@@ -55,7 +55,7 @@ class Beaker:
 
     """
 
-    RECOVERABLE_SERVER_ERROR_CODES = (429, 502, 503, 504)
+    RECOVERABLE_SERVER_ERROR_CODES = (429, 500, 502, 503, 504)
     MAX_RETRIES = 5
     API_VERSION = "v3"
 
